@@ -12,7 +12,6 @@
 #
 
 """Octavia API Library"""
-import functools
 
 from osc_lib.api import api
 
@@ -51,13 +50,6 @@ class OctaviaAPI(api.BaseAPI):
         self.endpoint = self.endpoint.rstrip('/')
         self._build_url()
 
-        # Make sure we are always requesting JSON responses
-        JSON_HEADER = {'Accept': 'application/json'}
-        self._create = functools.partial(self.create, headers=JSON_HEADER)
-        self._delete = functools.partial(self.delete, headers=JSON_HEADER)
-        self._find = functools.partial(self.find, headers=JSON_HEADER)
-        self._list = functools.partial(self.list, headers=JSON_HEADER)
-
     def _build_url(self):
         if not self.endpoint.endswith(self._endpoint_suffix):
             self.endpoint += self._endpoint_suffix
@@ -71,7 +63,7 @@ class OctaviaAPI(api.BaseAPI):
             List of load balancers
         """
         url = const.BASE_LOADBALANCER_URL
-        response = self._list(url, **params)
+        response = self.list(url, **params)
 
         return response
 
@@ -83,7 +75,7 @@ class OctaviaAPI(api.BaseAPI):
         :return:
             A dict of the specified load balancer's settings
         """
-        response = self._find(path=const.BASE_LOADBALANCER_URL, value=lb_id)
+        response = self.find(path=const.BASE_LOADBALANCER_URL, value=lb_id)
 
         return response
 
@@ -97,7 +89,7 @@ class OctaviaAPI(api.BaseAPI):
             A dict of the created load balancer's settings
         """
         url = const.BASE_LOADBALANCER_URL
-        response = self._create(url, **params)
+        response = self.create(url, **params)
 
         return response
 
@@ -113,7 +105,7 @@ class OctaviaAPI(api.BaseAPI):
             Response Code from the API
         """
         url = const.BASE_SINGLE_LB_URL.format(uuid=lb_id)
-        response = self._delete(url, params=params)
+        response = self.delete(url, params=params)
 
         return response
 
@@ -129,7 +121,7 @@ class OctaviaAPI(api.BaseAPI):
             Response Code from API
         """
         url = const.BASE_SINGLE_LB_URL.format(uuid=lb_id)
-        response = self._create(url, method='PUT', **params)
+        response = self.create(url, method='PUT', **params)
 
         return response
 
@@ -142,7 +134,7 @@ class OctaviaAPI(api.BaseAPI):
             A dict of the specified load balancer's statistics
         """
         url = const.BASE_LB_STATS_URL.format(uuid=lb_id)
-        response = self._list(url, **kwargs)
+        response = self.list(url, **kwargs)
 
         return response
 
@@ -155,7 +147,7 @@ class OctaviaAPI(api.BaseAPI):
             A dict of the specified load balancer's status
         """
         url = const.BASE_LOADBALANCER_STATUS_URL.format(uuid=lb_id)
-        response = self._list(url, **kwargs)
+        response = self.list(url, **kwargs)
 
         return response
 
@@ -169,7 +161,7 @@ class OctaviaAPI(api.BaseAPI):
             Response Code from the API
         """
         url = const.BASE_LOADBALANCER_FAILOVER_URL.format(uuid=lb_id)
-        response = self._create(url, method='PUT')
+        response = self.create(url, method='PUT')
 
         return response
 
@@ -182,7 +174,7 @@ class OctaviaAPI(api.BaseAPI):
             List of listeners
         """
         url = const.BASE_LISTENER_URL
-        response = self._list(url, **kwargs)
+        response = self.list(url, **kwargs)
 
         return response
 
@@ -194,7 +186,7 @@ class OctaviaAPI(api.BaseAPI):
         :return:
             A dict of the specified listener's settings
         """
-        response = self._find(path=const.BASE_LISTENER_URL, value=listener_id)
+        response = self.find(path=const.BASE_LISTENER_URL, value=listener_id)
 
         return response
 
@@ -208,7 +200,7 @@ class OctaviaAPI(api.BaseAPI):
             A dict of the created listener's settings
         """
         url = const.BASE_LISTENER_URL
-        response = self._create(url, **kwargs)
+        response = self.create(url, **kwargs)
 
         return response
 
@@ -222,7 +214,7 @@ class OctaviaAPI(api.BaseAPI):
             Response Code from the API
         """
         url = const.BASE_SINGLE_LISTENER_URL.format(uuid=listener_id)
-        response = self._delete(url)
+        response = self.delete(url)
 
         return response
 
@@ -238,7 +230,7 @@ class OctaviaAPI(api.BaseAPI):
             Response Code from the API
         """
         url = const.BASE_SINGLE_LISTENER_URL.format(uuid=listener_id)
-        response = self._create(url, method='PUT', **kwargs)
+        response = self.create(url, method='PUT', **kwargs)
 
         return response
 
@@ -251,7 +243,7 @@ class OctaviaAPI(api.BaseAPI):
             A dict of the specified listener's statistics
         """
         url = const.BASE_LISTENER_STATS_URL.format(uuid=listener_id)
-        response = self._list(url, **kwargs)
+        response = self.list(url, **kwargs)
 
         return response
 
@@ -264,7 +256,7 @@ class OctaviaAPI(api.BaseAPI):
             List of pools
         """
         url = const.BASE_POOL_URL
-        response = self._list(url, **kwargs)
+        response = self.list(url, **kwargs)
 
         return response
 
@@ -273,12 +265,12 @@ class OctaviaAPI(api.BaseAPI):
         """Create a pool
 
         :param kwargs:
-            Parameters to create a listener with (expects json=)
+            Parameters to create a pool with (expects json=)
         :return:
             A dict of the created pool's settings
         """
         url = const.BASE_POOL_URL
-        response = self._create(url, **kwargs)
+        response = self.create(url, **kwargs)
 
         return response
 
@@ -292,7 +284,7 @@ class OctaviaAPI(api.BaseAPI):
             Response Code from the API
         """
         url = const.BASE_SINGLE_POOL_URL.format(pool_id=pool_id)
-        response = self._delete(url)
+        response = self.delete(url)
 
         return response
 
@@ -304,7 +296,7 @@ class OctaviaAPI(api.BaseAPI):
         :return:
             Dict of the specified pool's settings
         """
-        response = self._find(path=const.BASE_POOL_URL, value=pool_id)
+        response = self.find(path=const.BASE_POOL_URL, value=pool_id)
 
         return response
 
@@ -320,7 +312,7 @@ class OctaviaAPI(api.BaseAPI):
             Response Code from the API
         """
         url = const.BASE_SINGLE_POOL_URL.format(pool_id=pool_id)
-        response = self._create(url, method='PUT', **kwargs)
+        response = self.create(url, method='PUT', **kwargs)
 
         return response
 
@@ -335,7 +327,7 @@ class OctaviaAPI(api.BaseAPI):
             Response list members
         """
         url = const.BASE_MEMBER_URL.format(pool_id=pool_id)
-        response = self._list(url, **kwargs)
+        response = self.list(url, **kwargs)
 
         return response
 
@@ -352,7 +344,7 @@ class OctaviaAPI(api.BaseAPI):
             Response of member
         """
         url = const.BASE_MEMBER_URL.format(pool_id=pool_id)
-        response = self._find(path=url, value=member_id)
+        response = self.find(path=url, value=member_id)
 
         return response
 
@@ -368,7 +360,7 @@ class OctaviaAPI(api.BaseAPI):
             A member details on successful creation
         """
         url = const.BASE_MEMBER_URL.format(pool_id=pool_id)
-        response = self._create(url, **kwargs)
+        response = self.create(url, **kwargs)
 
         return response
 
@@ -385,7 +377,7 @@ class OctaviaAPI(api.BaseAPI):
         """
         url = const.BASE_SINGLE_MEMBER_URL.format(pool_id=pool_id,
                                                   member_id=member_id)
-        response = self._delete(url)
+        response = self.delete(url)
 
         return response
 
@@ -404,7 +396,7 @@ class OctaviaAPI(api.BaseAPI):
         """
         url = const.BASE_SINGLE_MEMBER_URL.format(pool_id=pool_id,
                                                   member_id=member_id)
-        response = self._create(url, method='PUT', **kwargs)
+        response = self.create(url, method='PUT', **kwargs)
 
         return response
 
@@ -417,7 +409,7 @@ class OctaviaAPI(api.BaseAPI):
             List of l7policies
         """
         url = const.BASE_L7POLICY_URL
-        response = self._list(url, **kwargs)
+        response = self.list(url, **kwargs)
 
         return response
 
@@ -431,7 +423,7 @@ class OctaviaAPI(api.BaseAPI):
             A dict of the created l7policy's settings
         """
         url = const.BASE_L7POLICY_URL
-        response = self._create(url, **kwargs)
+        response = self.create(url, **kwargs)
 
         return response
 
@@ -445,7 +437,7 @@ class OctaviaAPI(api.BaseAPI):
             Response Code from the API
         """
         url = const.BASE_SINGLE_L7POLICY_URL.format(policy_uuid=l7policy_id)
-        response = self._delete(url)
+        response = self.delete(url)
 
         return response
 
@@ -457,7 +449,7 @@ class OctaviaAPI(api.BaseAPI):
         :return:
             Dict of the specified l7policy's settings
         """
-        response = self._find(path=const.BASE_L7POLICY_URL, value=l7policy_id)
+        response = self.find(path=const.BASE_L7POLICY_URL, value=l7policy_id)
 
         return response
 
@@ -473,7 +465,7 @@ class OctaviaAPI(api.BaseAPI):
             Response Code from the API
         """
         url = const.BASE_SINGLE_L7POLICY_URL.format(policy_uuid=l7policy_id)
-        response = self._create(url, method='PUT', **kwargs)
+        response = self.create(url, method='PUT', **kwargs)
 
         return response
 
@@ -483,10 +475,10 @@ class OctaviaAPI(api.BaseAPI):
         :param kwargs:
             Parameters to filter on
         :return:
-            List of l7policies
+            List of l7rules
         """
         url = const.BASE_L7RULE_URL.format(policy_uuid=l7policy_id)
-        response = self._list(url, **kwargs)
+        response = self.list(url, **kwargs)
 
         return response
 
@@ -502,7 +494,7 @@ class OctaviaAPI(api.BaseAPI):
             A dict of the created l7rule's settings
         """
         url = const.BASE_L7RULE_URL.format(policy_uuid=l7policy_id)
-        response = self._create(url, **kwargs)
+        response = self.create(url, **kwargs)
 
         return response
 
@@ -511,7 +503,7 @@ class OctaviaAPI(api.BaseAPI):
         """Delete a l7rule
 
         :param string l7rule_id:
-            ID of of listener to delete
+            ID of of l7rule to delete
         :param string l7policy_id:
             ID of the l7policy for this l7rule
         :return:
@@ -519,7 +511,7 @@ class OctaviaAPI(api.BaseAPI):
         """
         url = const.BASE_SINGLE_L7RULE_URL.format(rule_uuid=l7rule_id,
                                                   policy_uuid=l7policy_id)
-        response = self._delete(url)
+        response = self.delete(url)
 
         return response
 
@@ -534,7 +526,7 @@ class OctaviaAPI(api.BaseAPI):
             Dict of the specified l7rule's settings
         """
         url = const.BASE_L7RULE_URL.format(policy_uuid=l7policy_id)
-        response = self._find(path=url, value=l7rule_id)
+        response = self.find(path=url, value=l7rule_id)
 
         return response
 
@@ -553,7 +545,7 @@ class OctaviaAPI(api.BaseAPI):
         """
         url = const.BASE_SINGLE_L7RULE_URL.format(rule_uuid=l7rule_id,
                                                   policy_uuid=l7policy_id)
-        response = self._create(url, method='PUT', **kwargs)
+        response = self.create(url, method='PUT', **kwargs)
 
         return response
 
@@ -566,7 +558,7 @@ class OctaviaAPI(api.BaseAPI):
             A dict containing a list of health monitors
         """
         url = const.BASE_HEALTH_MONITOR_URL
-        response = self._list(url, **kwargs)
+        response = self.list(url, **kwargs)
 
         return response
 
@@ -580,7 +572,7 @@ class OctaviaAPI(api.BaseAPI):
             A dict of the created health monitor's settings
         """
         url = const.BASE_HEALTH_MONITOR_URL
-        response = self._create(url, **kwargs)
+        response = self.create(url, **kwargs)
 
         return response
 
@@ -595,7 +587,7 @@ class OctaviaAPI(api.BaseAPI):
         """
         url = const.BASE_SINGLE_HEALTH_MONITOR_URL.format(
             uuid=health_monitor_id)
-        response = self._delete(url)
+        response = self.delete(url)
 
         return response
 
@@ -608,7 +600,7 @@ class OctaviaAPI(api.BaseAPI):
             Dict of the specified health monitor's settings
         """
         url = const.BASE_HEALTH_MONITOR_URL
-        response = self._find(path=url, value=health_monitor_id)
+        response = self.find(path=url, value=health_monitor_id)
 
         return response
 
@@ -619,13 +611,13 @@ class OctaviaAPI(api.BaseAPI):
         :param health_monitor_id:
             ID of the health monitor to update
         :param kwargs:
-            A dict of arguments to update a l7policy
+            A dict of arguments to update a health monitor
         :return:
             Response Code from the API
         """
         url = const.BASE_SINGLE_HEALTH_MONITOR_URL.format(
             uuid=health_monitor_id)
-        response = self._create(url, method='PUT', **kwargs)
+        response = self.create(url, method='PUT', **kwargs)
 
         return response
 
@@ -638,7 +630,7 @@ class OctaviaAPI(api.BaseAPI):
             A ``dict`` representing a list of quotas for the project
         """
         url = const.BASE_QUOTA_URL
-        response = self._list(url, **params)
+        response = self.list(url, **params)
 
         return response
 
@@ -650,7 +642,7 @@ class OctaviaAPI(api.BaseAPI):
         :return:
             A ``dict`` representing the quota for the project
         """
-        response = self._find(path=const.BASE_QUOTA_URL, value=project_id)
+        response = self.find(path=const.BASE_QUOTA_URL, value=project_id)
 
         return response
 
@@ -664,7 +656,7 @@ class OctaviaAPI(api.BaseAPI):
             ``None``
         """
         url = const.BASE_SINGLE_QUOTA_URL.format(uuid=project_id)
-        response = self._delete(url)
+        response = self.delete(url)
 
         return response
 
@@ -680,7 +672,7 @@ class OctaviaAPI(api.BaseAPI):
             A ``dict`` representing the updated quota
         """
         url = const.BASE_SINGLE_QUOTA_URL.format(uuid=project_id)
-        response = self._create(url, method='PUT', **params)
+        response = self.create(url, method='PUT', **params)
 
         return response
 
@@ -691,7 +683,7 @@ class OctaviaAPI(api.BaseAPI):
             A ``dict`` representing a list of quota defaults
         """
         url = const.BASE_QUOTA_DEFAULT_URL
-        response = self._list(url)
+        response = self.list(url)
 
         return response
 
@@ -704,7 +696,7 @@ class OctaviaAPI(api.BaseAPI):
             A ``dict`` of the specified amphora's attributes
         """
         url = const.BASE_AMPHORA_URL
-        response = self._find(path=url, value=amphora_id)
+        response = self.find(path=url, value=amphora_id)
 
         return response
 
@@ -717,7 +709,199 @@ class OctaviaAPI(api.BaseAPI):
             A ``dict`` containing a list of amphorae
         """
         url = const.BASE_AMPHORA_URL
-        response = self._list(path=url, **kwargs)
+        response = self.list(path=url, **kwargs)
+
+        return response
+
+    @correct_return_codes
+    def amphora_configure(self, amphora_id):
+        """Update the amphora agent configuration
+
+        :param string amphora_id:
+            ID of the amphora to configure
+        :return:
+            Response Code from the API
+        """
+        url = const.BASE_AMPHORA_CONFIGURE_URL.format(uuid=amphora_id)
+        response = self.create(url, method='PUT')
+
+        return response
+
+    @correct_return_codes
+    def amphora_failover(self, amphora_id):
+        """Force failover an amphorae
+
+        :param string amphora_id:
+            ID of the amphora to failover
+        :return:
+            Response Code from the API
+        """
+        url = const.BASE_AMPHORA_FAILOVER_URL.format(uuid=amphora_id)
+        response = self.create(url, method='PUT')
+
+        return response
+
+    def provider_list(self):
+        """List all providers
+
+        :return:
+            A ``dict`` containing a list of provider
+        """
+        url = const.BASE_PROVIDER_URL
+        response = self.list(path=url)
+
+        return response
+
+    def provider_capability_list(self, provider):
+        """Show the flavor capability of the specified provider.
+
+        :param string provider:
+            The name of the provider to show
+        :return:
+            A ``dict`` containing the capabilicy of provider
+        """
+        url = const.BASE_PROVIDER_FLAVOR_CAPABILITY_URL.format(
+            provider=provider)
+        response = self.list(url)
+
+        return response
+
+    def flavor_list(self, **kwargs):
+        """List all flavors
+
+        :param kwargs:
+            Parameters to filter on
+        :return:
+            A ``dict`` containing a list of flavor
+        """
+        url = const.BASE_FLAVOR_URL
+        response = self.list(path=url, **kwargs)
+
+        return response
+
+    @correct_return_codes
+    def flavor_delete(self, flavor_id):
+        """Delete a flavor
+
+        :param string flavor_id:
+            ID of the flavor to delete
+        :return:
+            Response Code from the API
+        """
+        url = const.BASE_SINGLE_FLAVOR_URL.format(uuid=flavor_id)
+        response = self.delete(url)
+
+        return response
+
+    @correct_return_codes
+    def flavor_create(self, **kwargs):
+        """Create a flavor
+
+        :param kwargs:
+            Parameters to create a flavor with (expects json=)
+        :return:
+            A dict of the created flavor's settings
+        """
+        url = const.BASE_FLAVOR_URL
+        response = self.create(url, **kwargs)
+
+        return response
+
+    @correct_return_codes
+    def flavor_set(self, flavor_id, **kwargs):
+        """Update a flavor's settings
+
+        :param string flavor_id:
+            ID of the flavor to update
+        :param kwargs:
+            A dict of arguments to update a flavor
+        :return:
+            Response Code from the API
+        """
+        url = const.BASE_SINGLE_FLAVOR_URL.format(uuid=flavor_id)
+        response = self.create(url, method='PUT', **kwargs)
+
+        return response
+
+    def flavor_show(self, flavor_id):
+        """Show a flavor
+
+        :param string flavor_id:
+            ID of the flavor to show
+        :return:
+            A dict of the specified flavor's settings
+        """
+        response = self.find(path=const.BASE_FLAVOR_URL, value=flavor_id)
+
+        return response
+
+    @correct_return_codes
+    def flavorprofile_create(self, **kwargs):
+        """Create a flavor profile
+
+        :param kwargs:
+            Parameters to create a flavor profile with (expects json=)
+        :return:
+            A dict of the created flavor profile's settings
+        """
+        url = const.BASE_FLAVORPROFILE_URL
+        response = self.create(url, **kwargs)
+
+        return response
+
+    def flavorprofile_list(self, **kwargs):
+        """List all flavor profiles
+
+        :param kwargs:
+            Parameters to filter on
+        :return:
+            List of flavor profile
+        """
+        url = const.BASE_FLAVORPROFILE_URL
+        response = self.list(url, **kwargs)
+
+        return response
+
+    def flavorprofile_show(self, flavorprofile_id):
+        """Show a flavor profile
+
+        :param string flavorprofile_id:
+            ID of the flavor profile to show
+        :return:
+            A dict of the specified flavor profile's settings
+        """
+        response = self.find(path=const.BASE_FLAVORPROFILE_URL,
+                             value=flavorprofile_id)
+
+        return response
+
+    @correct_return_codes
+    def flavorprofile_set(self, flavorprofile_id, **kwargs):
+        """Update a flavor profile's settings
+
+        :param string flavorprofile_id:
+            ID of the flavor profile to update
+        :kwargs:
+            A dict of arguments to update the flavor profile
+        :return:
+            Response Code from the API
+        """
+        url = const.BASE_SINGLE_FLAVORPROFILE_URL.format(uuid=flavorprofile_id)
+        response = self.create(url, method='PUT', **kwargs)
+
+        return response
+
+    @correct_return_codes
+    def flavorprofile_delete(self, flavorprofile_id):
+        """Delete a flavor profile
+
+        :param string flavorprofile_id:
+            ID of the flavor profile to delete
+        :return:
+            Response Code from the API
+        """
+        url = const.BASE_SINGLE_FLAVORPROFILE_URL.format(uuid=flavorprofile_id)
+        response = self.delete(url)
 
         return response
 
