@@ -161,7 +161,12 @@ def get_loadbalancer_attrs(client_manager, parsed_args):
         'cascade': ('cascade', lambda x: True),
         'provisioning_status': ('provisioning_status', str),
         'operating_status': ('operating_status', str),
-        'provider': ('provider', str)
+        'provider': ('provider', str),
+        'flavor': (
+            'flavor_id',
+            'flavors',
+            client_manager.load_balancer.flavor_list
+        ),
     }
 
     _attrs = vars(parsed_args)
@@ -206,6 +211,11 @@ def get_listener_attrs(client_manager, parsed_args):
         'timeout_member_connect': ('timeout_member_connect', int),
         'timeout_member_data': ('timeout_member_data', int),
         'timeout_tcp_inspect': ('timeout_tcp_inspect', int),
+        'client_ca_tls_container_ref': ('client_ca_tls_container_ref',
+                                        _format_str_if_need_treat_unset),
+        'client_authentication': ('client_authentication', str),
+        'client_crl_container_ref': ('client_crl_container_ref',
+                                     _format_str_if_need_treat_unset),
     }
 
     _attrs = vars(parsed_args)
@@ -242,7 +252,16 @@ def get_pool_attrs(client_manager, parsed_args):
         ),
         'session_persistence': ('session_persistence', _format_kv),
         'enable': ('admin_state_up', lambda x: True),
-        'disable': ('admin_state_up', lambda x: False)
+        'disable': ('admin_state_up', lambda x: False),
+        'tls_container_ref': ('tls_container_ref',
+                              _format_str_if_need_treat_unset),
+        'ca_tls_container_ref': ('ca_tls_container_ref',
+                                 _format_str_if_need_treat_unset),
+        'crl_container_ref': ('crl_container_ref',
+                              _format_str_if_need_treat_unset),
+
+        'enable_tls': ('tls_enabled', lambda x: True),
+        'disable_tls': ('tls_enabled', lambda x: False),
     }
 
     _attrs = vars(parsed_args)
@@ -297,6 +316,7 @@ def get_l7policy_attrs(client_manager, parsed_args):
         'name': ('name', str),
         'description': ('description', str),
         'redirect_url': ('redirect_url', str),
+        'redirect_http_code': ('redirect_http_code', int),
         'redirect_prefix': ('redirect_prefix', str),
         'l7policy': (
             'l7policy_id',
@@ -391,7 +411,9 @@ def get_health_monitor_attrs(client_manager, parsed_args):
         'max_retries_down': ('max_retries_down', int),
         'url_path': ('url_path', str),
         'enable': ('admin_state_up', lambda x: True),
-        'disable': ('admin_state_up', lambda x: False)
+        'disable': ('admin_state_up', lambda x: False),
+        'http_version': ('http_version', float),
+        'domain_name': ('domain_name', str)
     }
 
     _attrs = vars(parsed_args)
@@ -440,6 +462,57 @@ def get_amphora_attrs(client_manager, parsed_args):
     return _map_attrs(vars(parsed_args), attr_map)
 
 
+def get_provider_attrs(parsed_args):
+    attr_map = {
+        'provider': ('provider_name', str),
+        'description': ('description', str),
+    }
+
+    return _map_attrs(vars(parsed_args), attr_map)
+
+
+def get_flavor_attrs(client_manager, parsed_args):
+    attr_map = {
+        'name': ('name', str),
+        'flavor': (
+            'flavor_id',
+            'flavors',
+            client_manager.load_balancer.flavor_list,
+        ),
+        'flavorprofile': (
+            'flavor_profile_id',
+            'flavorprofiles',
+            client_manager.load_balancer.flavorprofile_list,
+        ),
+        'enable': ('enabled', lambda x: True),
+        'disable': ('enabled', lambda x: False),
+        'description': ('description', str),
+    }
+
+    _attrs = vars(parsed_args)
+    attrs = _map_attrs(_attrs, attr_map)
+
+    return attrs
+
+
+def get_flavorprofile_attrs(client_manager, parsed_args):
+    attr_map = {
+        'name': ('name', str),
+        'flavorprofile': (
+            'flavorprofile_id',
+            'flavorprofiles',
+            client_manager.load_balancer.flavorprofile_list,
+        ),
+        'provider': ('provider_name', str),
+        'flavor_data': ('flavor_data', str),
+    }
+
+    _attrs = vars(parsed_args)
+    attrs = _map_attrs(_attrs, attr_map)
+
+    return attrs
+
+
 def format_list(data):
     return '\n'.join(i['id'] for i in data)
 
@@ -459,3 +532,9 @@ def _format_kv(data):
         formatted_kv[k] = v
 
     return formatted_kv
+
+
+def _format_str_if_need_treat_unset(data):
+    if data.lower() in ('none', 'null', 'void'):
+        return None
+    return str(data)
