@@ -16,57 +16,27 @@ import mock
 
 from osc_lib import exceptions
 
+from octaviaclient.osc.v2 import constants
 from octaviaclient.osc.v2 import health_monitor
-from octaviaclient.tests.unit.osc.v2 import fakes as hm_fakes
-
-AUTH_TOKEN = "foobar"
-AUTH_URL = "http://192.0.2.2"
+from octaviaclient.tests.unit.osc.v2 import constants as attr_consts
+from octaviaclient.tests.unit.osc.v2 import fakes
 
 
-class TestHealthMonitor(hm_fakes.TestOctaviaClient):
-
-    _hm = hm_fakes.FakeHM.create_one_health_monitor()
-
-    columns = ('id', 'name', 'project_id', 'type', 'admin_state_up')
-
-    datalist = (
-        (
-            _hm.id,
-            _hm.name,
-            _hm.project_id,
-            _hm.type,
-            _hm.admin_state_up
-        ),
-    )
-
-    info = {
-        'healthmonitors':
-            [{
-                "project_id": _hm.project_id,
-                "name": _hm.name,
-                "admin_state_up": True,
-                "pools": _hm.pools,
-                "created_at": _hm.created_at,
-                "delay": _hm.delay,
-                "expected_codes": _hm.expected_codes,
-                "max_retries": _hm.max_retries,
-                "http_method": _hm.http_method,
-                "timeout": _hm.timeout,
-                "max_retries_down": _hm.max_retries_down,
-                "url_path": _hm.url_path,
-                "type": _hm.type,
-                "id": _hm.id
-            }]
-    }
-    hm_info = copy.deepcopy(info)
+class TestHealthMonitor(fakes.TestOctaviaClient):
 
     def setUp(self):
         super(TestHealthMonitor, self).setUp()
-        self.li_mock = self.app.client_manager.load_balancer.load_balancers
-        self.li_mock.reset_mock()
 
+        self._hm = fakes.createFakeResource('hm')
+        self.hm_info = copy.deepcopy(attr_consts.HM_ATTRS)
+        self.columns = copy.deepcopy(constants.MONITOR_COLUMNS)
+
+        info_list = {'healthmonitors': [
+            {k: v for k, v in attr_consts.HM_ATTRS.items() if (
+                k in self.columns)},
+        ]}
         self.api_mock = mock.Mock()
-        self.api_mock.health_monitor_list.return_value = self.hm_info
+        self.api_mock.health_monitor_list.return_value = info_list
         lb_client = self.app.client_manager
         lb_client.load_balancer = self.api_mock
 
@@ -75,6 +45,7 @@ class TestHealthMonitorList(TestHealthMonitor):
 
     def setUp(self):
         super(TestHealthMonitorList, self).setUp()
+        self.datalist = (tuple(attr_consts.HM_ATTRS[k] for k in self.columns),)
         self.cmd = health_monitor.ListHealthMonitor(self.app, None)
 
     def test_health_monitor_list_no_options(self):
@@ -123,7 +94,7 @@ class TestHealthMonitorCreate(TestHealthMonitor):
         super(TestHealthMonitorCreate, self).setUp()
         self.api_mock = mock.Mock()
         self.api_mock.health_monitor_create.return_value = {
-            'healthmonitor': self.hm_info['healthmonitors'][0]}
+            'healthmonitor': self.hm_info}
         lb_client = self.app.client_manager
         lb_client.load_balancer = self.api_mock
 
@@ -131,36 +102,41 @@ class TestHealthMonitorCreate(TestHealthMonitor):
 
     @mock.patch('octaviaclient.osc.v2.utils.get_health_monitor_attrs')
     def test_health_monitor_create(self, mock_client):
-        mock_client.return_value = self.hm_info['healthmonitors'][0]
+        mock_client.return_value = self.hm_info
         arglist = ['mock_pool_id',
                    '--name', self._hm.name,
                    '--delay', str(self._hm.delay),
                    '--timeout', str(self._hm.timeout),
                    '--max-retries', str(self._hm.max_retries),
-                   '--type', self._hm.type]
+                   '--type', self._hm.type.lower(),
+                   '--http-method', self._hm.http_method.lower(),
+                   '--http-version', str(self._hm.http_version),
+                   '--domain-name', self._hm.domain_name]
         verifylist = [
             ('pool', 'mock_pool_id'),
             ('name', self._hm.name),
             ('delay', str(self._hm.delay)),
             ('timeout', str(self._hm.timeout)),
             ('max_retries', self._hm.max_retries),
-            ('type', self._hm.type)
+            ('type', self._hm.type),
+            ('http_method', self._hm.http_method),
+            ('http_version', self._hm.http_version),
+            ('domain_name', self._hm.domain_name)
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
         self.api_mock.health_monitor_create.assert_called_with(
-            json={'healthmonitor': self.hm_info['healthmonitors'][0]})
+            json={'healthmonitor': self.hm_info})
 
 
 class TestHealthMonitorShow(TestHealthMonitor):
 
     def setUp(self):
         super(TestHealthMonitorShow, self).setUp()
-        self.api_mock = mock.Mock()
-        self.api_mock.health_monitor_list.return_value = self.hm_info
-        self.api_mock.health_monitor_show.return_value = (
-            self.hm_info['healthmonitors'][0])
+        self.api_mock.health_monitor_show.return_value = {
+            'healthmonitor': self.hm_info,
+        }
         lb_client = self.app.client_manager
         lb_client.load_balancer = self.api_mock
 
@@ -185,13 +161,19 @@ class TestHealthMonitorSet(TestHealthMonitor):
         self.cmd = health_monitor.SetHealthMonitor(self.app, None)
 
     def test_health_monitor_set(self):
-        arglist = [self._hm.id, '--name', 'new_name']
+        arglist = [self._hm.id, '--name', 'new_name',
+                   '--http-version', str(self._hm.http_version),
+                   '--domain-name', self._hm.domain_name]
         verifylist = [
             ('health_monitor', self._hm.id),
-            ('name', 'new_name')
+            ('name', 'new_name'),
+            ('http_version', self._hm.http_version),
+            ('domain_name', self._hm.domain_name)
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
         self.api_mock.health_monitor_set.assert_called_with(
-            self._hm.id, json={'healthmonitor': {'name': 'new_name'}})
+            self._hm.id, json={'healthmonitor': {
+                'name': 'new_name', 'http_version': self._hm.http_version,
+                'domain_name': self._hm.domain_name}})
